@@ -14,11 +14,11 @@ def create_global_key_to_data_row_dict(client:labelboxClient, global_keys:list,
     """    
     global_key_to_data_row_dict = {}
     for i in range(0, len(global_keys), batch_size):
-        gks = global_keys_list[i:] if i + batch_size >= len(global_keys_list) else global_keys_list[i:i+batch_size] # Batch of global keys   
+        gks = global_keys[i:] if i + batch_size >= len(global_keys) else global_keys[i:i+batch_size] # Batch of global keys   
         res = client.get_data_row_ids_for_global_keys(gks, timeout_seconds=600)
         if res['errors']:
             raise ValueError(f"{res}")
-        global_key_to_data_row_dict.update({global_keys[i] : res['results'][i] for i in range(0, len(global_keys))})
+        global_key_to_data_row_dict.update({gks[i] : res['results'][i] for i in range(0, len(gks))})
     return global_key_to_data_row_dict
 
 def check_global_keys(client:labelboxClient, global_keys:list):
